/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _U2_GENOME_ALIGNER_PLUGIN_H_
#define _U2_GENOME_ALIGNER_PLUGIN_H_

#include <U2Core/PluginModel.h>

namespace U2 {

class GenomeAlignerPlugin : public Plugin  {
    Q_OBJECT
public:
    GenomeAlignerPlugin();
    ~GenomeAlignerPlugin();
};

} //namespace

#endif // _U2_GENOME_ALIGNER_PLUGIN_H_
